@@ -155,10 +155,11 @@ class WheyParser(AbstractConfigParser):
 
 	def parse_additional_files(self, config: Dict[str, TOML_TYPES]) -> List[str]:
 		"""
-		Parse the ``additional-files`` key,
-		giving `MANIFEST.in <https://packaging.python.org/guides/using-manifest-in/>`_-style
+		Parse the ``additional-files`` key, giving `MANIFEST.in`_-style
 		entries for additional files to include in distributions.
 
+		.. _MANIFEST.in: https://packaging.python.org/guides/using-manifest-in/
+
 		:param config: The unparsed TOML config for the ``[tool.whey]`` table.
 		"""  # noqa: D400
 
@@ -196,7 +197,8 @@ class WheyParser(AbstractConfigParser):
 		for idx, version in enumerate(python_versions):
 			if not isinstance(version, (str, int, float)):
 				raise TypeError(
-						f"Invalid type for 'tool.whey.python-versions[{idx}]': expected {str!r}, {int!r} or {float!r}, got {type(version)!r}"
+						f"Invalid type for 'tool.whey.python-versions[{idx}]': "
+						f"expected {str!r}, {int!r} or {float!r}, got {type(version)!r}"
 						)
 			if str(version) in "12":
 				raise BadConfigError(
@@ -338,11 +340,12 @@ def backfill_classifiers(config: Dict[str, TOML_TYPES]) -> List[str]:
 
 def get_entry_points() -> Iterable[importlib_metadata.EntryPoint]:
 	r"""
-	Returns an iterable over `EntryPoint <https://docs.python.org/3/library/importlib.metadata.html#entry-points>`_
-	objects in the ``whey.builder`` group.
+	Returns an iterable over `EntryPoint`_ objects in the ``whey.builder`` group.
 
-	:rtype: :class:`Iterable <typing.Iterable>`\[`EntryPoint <https://docs.python.org/3/library/importlib.metadata.html#entry-points>`_\]
-	"""  # noqa: D400
+	:rtype: :class:`Iterable <typing.Iterable>`\[`EntryPoint`_\]
+
+	.. _EntryPoint: https://docs.python.org/3/library/importlib.metadata.html#entry-points
+	"""
 
 	eps = itertools.chain.from_iterable(dist.entry_points for dist in importlib_metadata.distributions())
 
